@@ -61,11 +61,14 @@ def finish_time(c_file, elapsed):
 def overall_time(elapsed_all):
     logging.info("[OVERALL TIME]: %s", elapsed_all)
 
-def summary(n_files, n_func, n_cex):
+def summary(n_files, n_func, n_cex, time, memory):
     print("\n########################################")
     print("Summary:\n")
     print("Files Verified: ", n_files)
     print("Functions Verified: ", n_func)
     print("Counterexamples: ", n_cex)
+    print("")
+    print(f"Overall time: {round(time,2)}s")
+    print(f"Peak Memory Usage: {round((memory / 10**6),2)}MB")
     print("########################################\n")
 
